@@ -1,6 +1,6 @@
 package IPC::SRLock::Memcached;
 
-# @(#)$Id: Memcached.pm 39 2008-04-28 11:47:55Z pjf $
+# @(#)$Id: Memcached.pm 52 2008-05-23 17:12:42Z pjf $
 
 use strict;
 use warnings;
@@ -9,7 +9,7 @@ use Cache::Memcached;
 use Readonly;
 use Time::HiRes qw(usleep);
 
-use version; our $VERSION = qv( sprintf '0.1.%d', q$Rev: 39 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.1.%d', q$Rev: 52 $ =~ /\d+/gmx );
 
 Readonly my %ATTRS => ( lockfile  => q(_lockfile),
                         memd      => undef,
@@ -138,6 +138,117 @@ sub _sleep_or_throw {
 
 __END__
 
+=pod
+
+=head1 Name
+
+IPC::SRLock::Memcached - Set/reset locks using libmemcache
+
+=head1 Version
+
+0.1.$Revision: 52 $
+
+=head1 Synopsis
+
+   use IPC::SRLock;
+
+   my $config = { tempdir => q(path_to_tmp_directory), type => q(memcached) };
+
+   my $lock_obj = IPC::SRLock->new( $config );
+
+=head1 Description
+
+Uses L<Cache::Memcached> to implement a distributed lock manager
+
+=head1 Configuration and Environment
+
+This class defines accessors and mutators for these attributes:
+
+=over 3
+
+=item lockfile
+
+Name of the key to the lock file record. Defaults to I<_lockfile>
+
+=item memd
+
+An instance of L<Cache::Memcached> with it's namespace set to I<ipc_srlock>
+
+=item servers
+
+An array ref of servers to connect to. Defaults to I<localhost:11211>
+
+=item shmfile
+
+Name of the key to the lock table record. Defaults to I<_shmfile>
+
+=back
+
+=head1 Subroutines/Methods
+
+=head2 _init
+
+Initialise the object
+
+=head2 _list
+
+List the contents of the lock table
+
+=head2 _reset
+
+Delete a lock from the lock table
+
+=head2 _set
+
+Set a lock in the lock table
+
+=head2 _sleep_or_throw
+
+Sleep for a bit or throw a timeout exception
+
+=head1 Diagnostics
+
+None
+
+=head1 Dependencies
+
+=over 4
+
+=item L<IPC::SRLock>
+
+=item L<Cache::Memcached>
+
+=item L<Readonly>
+
+=back
+
+=head1 Incompatibilities
+
+There are no known incompatibilities in this module
+
+=head1 Bugs and Limitations
+
+There are no known bugs in this module.
+Please report problems to the address below.
+Patches are welcome
+
+=head1 Author
+
+Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
+
+=head1 License and Copyright
+
+Copyright (c) 2008 Peter Flanigan. All rights reserved
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself. See L<perlartistic>
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE
+
+=cut
+
 # Local Variables:
 # mode: perl
 # tab-width: 3
